@@ -15,20 +15,6 @@ logging.basicConfig(
     format='[%(asctime)s] [%(levelname)s] %(message)s'
 )
 
-# 日志服务的WebSocket连接
-logs_ws_home = os.environ.get('LOG_WEBSOCKET', None)
-logs_ws_mark_application = os.environ.get('LOG_MARK_APPLICATION', None)
-logs_ws_mark_component = os.environ.get('LOG_MARK_COMPONENT', None)
-if logs_ws_home and logs_ws_mark_application and logs_ws_mark_component:
-    try:
-        logs_ws_url = 'ws://{0}/logs/websocket/{1}/{2}'.format(
-            logs_ws_home, logs_ws_mark_application, logs_ws_mark_component)
-        logs_ws = create_connection(logs_ws_url)
-    except Exception as err:
-        logs_ws = None
-else:
-    logs_ws = None
-
 
 def handle_date(date: str, date_type='start') -> datetime:
     try:
@@ -147,13 +133,6 @@ def handle_abnormal(message: str, status: int, header: dict = {'Content-Type': '
         'host_ip': socket.gethostbyname(host_name),
     }
     return_body.update(other)
-    if logs_ws and logs_ws.connected:
-        # 在日志服务的WS连接操作时，向日志服务发送信息
-        try:
-            logs_ws.send('[{0}] [{1}] {2}'.format(
-                server_time.strftime('%Y-%m-%d %H:%M:%S.%f'), status, message))
-        except Exception as err:
-            logs_ws.close()  # 信息发送失败时，认为日志服务不可用，关闭连接
     if is_raw:
         return return_body, status, header
     else:
